pub enum ErrorType {
ClosingTagMismatch {
expected: String,
got: String,
},
NotFound(&'static str),
UnexpectedEnd,
UnexpectedClosingTag,
}Expand description
Represents the type of minification error.
Show fields
Fields of ClosingTagMismatch
Generates an English message describing the error with any additional context.
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.