Struct minify_html::Cfg[][src]

pub struct Cfg {
    pub minify_js: bool,
    pub minify_css: bool,
}
Configuration settings that can be adjusted and passed to a minification function to change the minification approach.

Fields

minify_js: bool

If enabled, JavaScript in <script> tags are minified using esbuild-rs. The js-esbuild feature must be enabled; otherwise, this value has no effect.

Only <script> tags with a valid or no MIME type is considered to contain JavaScript, as per the specification.

minify_css: bool

If enabled, CSS in <style> tags are minified using esbuild-rs. The js-esbuild feature must be enabled; otherwise, this value has no effect.