pub struct FriendlyError {
pub position: usize,
pub message: String,
pub code_context: String,
}Expand description
User-friendly details about a minification failure, including an English message description of
the reason, and generated printable contextual representation of the code where the error
occurred.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.