Struct minify_html::Cfg [−][src]
Configuration settings that can be adjusted and passed to a minification function to change the minification approach.
Fields
minify_js: boolIf enabled, JavaScript in <script> tags are minified using
esbuild-rs. The js-esbuild feature must be
enabled; otherwise, this value has no effect.
Only <script> tags with a valid or no
MIME type is considered to
contain JavaScript, as per the specification.
minify_css: boolIf enabled, CSS in <style> tags are minified using
esbuild-rs. The js-esbuild feature must be
enabled; otherwise, this value has no effect.